pub struct YieldOperation<'c> { /* private fields */ }Expand description
A yield operation. Terminates and yields values from vector regions..
“vector.yield” yields an SSA value from the Vector dialect op region and terminates the regions. The semantics of how the values are yielded is defined by the parent operation. If “vector.yield” has any operands, the operands must correspond to the parent operation’s results. If the parent operation defines no value the vector.yield may be omitted when printing the region.
Implementations
Sourceimpl<'c> YieldOperation<'c>
impl<'c> YieldOperation<'c>